import Vue from 'vue';
import { Messages, Metadata } from '@zeedhi/core';
import App from './App.vue';
import router from './router';
import { vuetify } from './plugins';
import store from './store';
import './components';
import './registerServiceWorker';
import 'roboto-fontface/css/roboto/roboto-fontface.css';
import './styles/style.scss';

Vue.config.productionTip = false;

const loadMessages = async () => {
  const messages = await Metadata.get('../json/messages', true);
  const wordsEsCl = await Metadata.get('../json/words/es_cl', true); // Espanhol padrão
  const wordsEnUs = await Metadata.get('../json/words/en_us', true); // Inglês padrão
  const wordsEsCo = await Metadata.get('../json/words/es_co', true);
  const wordsEsEs = await Metadata.get('../json/words/es_es', true);

  Messages.add({
    'pt-BR': {
      translation: {
        ...messages,
      },
    },
    'es-CL': {
      translation: {
        ...wordsEsCl,
      },
    },
    'es-CO': {
      translation: {
        ...wordsEsCo,
      },
    },
    'es-ES': {
      translation: {
        ...wordsEsEs,
      },
    },
    'en-US': {
      translation: {
        ...wordsEnUs,
      },
    },
  });
};

loadMessages().then(() => {
  new Vue({
    router,
    vuetify,
    store,
    render: (h) => h(App),
  }).$mount('#app');
});
